Stream handlers — BCI-Framework documentation

# Stream handlers

class `bci_framework.framework.extensions_handler.` `ExtensionMenu`

  MDIArea menu for extensions.

  `build_menu_stimuli`(visualization: bool, debugger: Optional[bool] = False) → None

    Menu for stimuli delivery.

  `build_menu_visualization`(visualization: bool, debugger: Optional[bool] = False) → None

    Menu for visualizations.

  `set_dpi`(menu_dpi, text: str, dpi: int) → Callable

    Set the DPI value for matplotlib figures.

  `set_extension`(visualization: str) → Callable

    Load extension from menu.

class `bci_framework.framework.extensions_handler.` `ExtensionWidget`(mdi_area, mode: str, extensions_list: List[str] = [], autostart: Optional[str] = None, hide_menu: Optional[bool] = False, directory: Optional[str] = None)

  MDIArea with extension.

  `load_extension`(extension: str, debugger: Optional[bool] = False) → None

    Load project.

  `loaded`(*args, **kwargs) → None

    Method to connect events.

  `reload`() → None

    Restart process.

  `remove`() → None

    Remove active extension.

  `save_img`(name: Optional[str] = None) → None

    Save capture of visualization in the project directory.

  `stop_preview`() → None

    Stop process.

  `update_ip`(*args, **kwargs) → None

    Method to connect events.

  `update_menu_bar`(visualization: Optional[bool] = None, debugger: Optional[bool] = False) → None

    Create menubar.